package com.alipay.api.domain;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;

/**
 * 间连商户地址信息
 *
 * @author auto create
 * @since 1.0, 2018-02-26 15:27:53
 */
public class AddressInfo extends AlipayObject {

    private static final long serialVersionUID = 5662894829563172956L;

    /**
     * 地址。商户详细经营地址或人员所在地点
     */
    @ApiField("address")
    private String address;

    /**
     * 城市编码，城市编码是与国家统计局一致，请查询:
     * http://www.stats.gov.cn/tjsj/tjbz/tjyqhdmhcxhfdm/
     * 国标省市区号下载：http://aopsdkdownload.cn-hangzhou.alipay-pub.aliyun-inc.com/doc/2016.xls?spm=a219a.7629140.0.0.qRW4KQ&file=2016.xls
     */
    @ApiField("city_code")
    private String cityCode;

    /**
     * 区县编码，区县编码是与国家统计局一致，请查询: http://www.stats.gov.cn/tjsj/tjbz/tjyqhdmhcxhfdm/ 国标省市区号下载：http://aopsdkdownload.cn-hangzhou.alipay-pub.aliyun-inc.com/doc/2016.xls?spm=a219a.7629140.0.0.qRW4KQ&file=2016.xls
     */
    @ApiField("district_code")
    private String districtCode;

    /**
     * 纬度，浮点型,小数点后最多保留6位
     * 如需要录入经纬度，请以高德坐标系为准，录入时请确保经纬度参数准确。高德经纬度查询：http://lbs.amap.com/console/show/picker
     */
    @ApiField("latitude")
    private String latitude;

    /**
     * 经度，浮点型, 小数点后最多保留6位。
     * 如需要录入经纬度，请以高德坐标系为准，录入时请确保经纬度参数准确。高德经纬度查询：http://lbs.amap.com/console/show/picker
     */
    @ApiField("longitude")
    private String longitude;

    /**
     * 省份编码，
     * 省份编码是与国家统计局一致，请查询:
     * http://www.stats.gov.cn/tjsj/tjbz/tjyqhdmhcxhfdm/
     * 国标省市区号下载：http://aopsdkdownload.cn-hangzhou.alipay-pub.aliyun-inc.com/doc/2016.xls?spm=a219a.7629140.0.0.qRW4KQ&file=2016.xls
     */
    @ApiField("province_code")
    private String provinceCode;

    /**
     * 地址类型。取值范围：BUSINESS_ADDRESS：经营地址（默认）
     */
    @ApiField("type")
    private String type;

    public String getAddress() {
        return this.address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getCityCode() {
        return this.cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }

    public String getDistrictCode() {
        return this.districtCode;
    }

    public void setDistrictCode(String districtCode) {
        this.districtCode = districtCode;
    }

    public String getLatitude() {
        return this.latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }

    public String getLongitude() {
        return this.longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getProvinceCode() {
        return this.provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }

    public String getType() {
        return this.type;
    }

    public void setType(String type) {
        this.type = type;
    }

}
