package com.alipay.api.domain;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;

/**
 * 通过此接口，商户可以出传入item_id与上下架标识，对商户创建的商品进行上架或下架处理
 *
 * @author auto create
 * @since 1.0, 2017-04-20 15:17:50
 */
public class AlipayOfflineMarketItemStateModel extends AlipayObject {

    private static final long serialVersionUID = 6236174188999614587L;

    /**
     * 审核规则。支付宝内部使用，外部商户不需填写此字段。
     */
    @ApiField("audit_rule")
    private AlipayItemAuditRule auditRule;

    /**
     * 口碑体系内部商品的唯一标识
     */
    @ApiField("item_id")
    private String itemId;

    /**
     * 备注
     */
    @ApiField("memo")
    private String memo;

    /**
     * 商户通知地址，口碑发消息给商户通知其是否对商品创建、修改、变更状态成功
     */
    @ApiField("operate_notify_url")
    private String operateNotifyUrl;

    /**
     * 商品操作上下文。支付宝内部使用，外部商户不需填写此字段。
     */
    @ApiField("operation_context")
    private AlipayItemOperationContext operationContext;

    /**
     * 支持英文字母和数字，由开发者自行定义（不允许重复），在商品notify消息中也会带有该参数，以此标明本次notify消息是对哪个请求的回应
     */
    @ApiField("request_id")
    private String requestId;

    /**
     * 商品上下架
     */
    @ApiField("state_type")
    private String stateType;

    public AlipayItemAuditRule getAuditRule() {
        return this.auditRule;
    }

    public void setAuditRule(AlipayItemAuditRule auditRule) {
        this.auditRule = auditRule;
    }

    public String getItemId() {
        return this.itemId;
    }

    public void setItemId(String itemId) {
        this.itemId = itemId;
    }

    public String getMemo() {
        return this.memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getOperateNotifyUrl() {
        return this.operateNotifyUrl;
    }

    public void setOperateNotifyUrl(String operateNotifyUrl) {
        this.operateNotifyUrl = operateNotifyUrl;
    }

    public AlipayItemOperationContext getOperationContext() {
        return this.operationContext;
    }

    public void setOperationContext(AlipayItemOperationContext operationContext) {
        this.operationContext = operationContext;
    }

    public String getRequestId() {
        return this.requestId;
    }

    public void setRequestId(String requestId) {
        this.requestId = requestId;
    }

    public String getStateType() {
        return this.stateType;
    }

    public void setStateType(String stateType) {
        this.stateType = stateType;
    }

}
